'-------------------------------------------------------------------------
'  Megatokyo.vbs (v2.1)
'-------------------------------------------------------------------------
'
' Writes the date and name of the current comic and the percentage
' completion of the next comic to a temp file on lines 1, 2 and 3
' respectively.

' NOTES:
'
' - Execute the "updateComicInfo" function to update the comic information. 
' Ignore any warnings from antivirus software that this is a malicious script
' (it just writes a small .tmp file to your Samurize directory to store the
' comic information)
'
' - Add text file meters to retreive the information from this temp file.
'   For example, to get the name of the latest comic, add a Text File meter
'   with its "Text File To Read From" field as the mt.tmp file, its 
'   "Read Line" field as 2 and its "Number of Lines" field as 1. A sample
'   config file is included if you get stuck :)
'
' - If you are using a version of Samurize prior to v0.85b, set the
'   ENABLE_LINKAGE setting below to false.
'
' Version history:
'
' v2.1: Added link! Now if you Allow Meter-Linkage for a textfile meter that 
'       reads the comic name (read line 2 of the text file), double-clicking
'       it will open the new comic in a browser window.
'	Hid relevant functions from Samurize 0.85b
'
' v2.0: Rewrote the script to use a text file to save bandwidth.
'	Added percentage completion return value.
'	Added display date options.
'
'								-NeM
'-------------------------------------------------------------------------

'==============================================================================
' USER VARIABLES
' feel free to change these.

ENABLE_LINKAGE = true	' set to false if you are using a Samurize version
			' BEFORE 0.85b

TMP_NAME = "mt.tmp"	' tmp file name
UPDATE_INTERVAL = 120	' num of minutes before the comic info will be updated
			' (added to save bandwidth)

' Please choose the style you want the date to appear as.
' eg. for the 21st of Febuary 2003:
' (1) 21 Feb
' (2) 21 Feb 03
' (3) 21/02
' (4) 21/02/03
' (5) 2003-02-21

DATE_STYLE = 5

'==============================================================================

Function updateComicInfo()

	dim html, text, b

	elapsedTime = TimeDiff(TMP_NAME)

	if elapsedTime > UPDATE_INTERVAL or elapsedTime = -1 Then

		b = chr(13) & chr(10)
		html = ReturnHTML("http://www.megatokyo.com")

		text = formattedDate(getComicDate(html)) & b & getComicName(html)

		if ENABLE_LINKAGE = true then

			text = text & "%l" & "http://www.megatokyo.com" & getComicLink(html)

		end if


		text = text & b & getNextComicPercent(html)

		set fs=CreateObject("Scripting.FileSystemObject")
		set f=fs.CreateTextFile(TMP_NAME,true)
		f.write(text)
		f.close
		set f=nothing
		set fs=nothing
	End If

End Function

' ===========================================================================
' The following functions are only helper functions (not for use by Samurize)
' ===========================================================================

Private Function formattedDate(Date)

	style = Date

	If DATE_STYLE = 5 Then
		formattedDate = style
		Exit Function
	End If

	If DATE_STYLE > 2 Then
		dateString = mid(style, 9, 2) & "/" & mid(style, 6, 2)
		If DATE_STYLE = 4 Then
			dateString = dateString & "/" & mid(style, 3, 2)
		End If
	End If

	If DATE_STYLE < 3 Then
		dateString = mid(style, 9, 2) & " " & numToMonthName(CInt(mid(style, 6, 2)))
		If DATE_STYLE = 2 Then
			dateString = dateString & " " & mid(style, 3, 2)
		End If
	End If

	formattedDate = dateString

End Function



Private Function getNextComicPercent(pageHTML)


	dim htmlResult, nextPercent
	htmlResult = pageHTML

	pageUp = instr(htmlResult, "<title> MegaTokyo - relax, we understand j00</title>")

	if pageUp > 0 then

		htmlResult = Mid(htmlResult, InStr(htmlResult, "<IMG SRC=""parts/pix-dark.gif"))
		
		leftMark = instr( pageUp, htmlResult, "&nbsp")+5

		rightMark = instr( leftMark, htmlResult, "%")

		if leftMark > 0 AND rightMark > leftMark Then

			nextPercent = right(mid( htmlResult, leftMark+1, rightMark-leftMark-1 ), rightMark-leftMark-1)

		end if

	Else
		nextPercent = "Latest comic % not available."

	end if

	getNextComicPercent = nextPercent

End Function





Private Function getComicDate(pageHTML)

	dim htmlResult, comicDate
	htmlResult = pageHTML

	pageUp = instr(htmlResult, "<title> MegaTokyo - relax, we understand j00</title>")

	if pageUp > 0 then

		htmlResult = Mid(htmlResult, InStr(htmlResult, "<option value='")+14)
		htmlResult = Mid(htmlResult, InStr(htmlResult, "<option value='"))
		
		leftMark = instr( pageUp, htmlResult, ">")

		rightMark = instr( leftMark, htmlResult, " [")

		if leftMark > 0 AND rightMark > leftMark Then

			'grabs the date of the comic
			comicDate = right(mid( htmlResult, leftMark+1, rightMark-leftMark-1 ), rightMark-leftMark-1)

		end if

	Else
		getComicDate = "Latest comic name not available."

	end if

	getComicDate = comicDate

End Function

Private Function getComicName(pageHTML)

	dim htmlResult, comicName, comicLink
	htmlResult = pageHTML

	pageUp = instr(htmlResult, "<title> MegaTokyo - relax, we understand j00</title>")

	if pageUp > 0 then

		htmlResult = Mid(htmlResult, InStr(htmlResult, "<option value='"))
		htmlResult = Mid(htmlResult, InStr(htmlResult, "<option value='"))
		
		leftMark = instr( pageUp, htmlResult, "] ")

		rightMark = instr( leftMark, htmlResult, "</option>")

		if leftMark > 0 AND rightMark > leftMark Then

			'grabs the name of the comic
			comicName = right(mid( htmlResult, leftMark+1, rightMark-leftMark-1 ), rightMark-leftMark-2)

		end if

	Else
		getComicName = "Latest comic name not available."

	end if

	getComicName = comicName

End Function

Private Function getComicLink(pageHTML)

	dim htmlResult, comicLink
	htmlResult = pageHTML

	pageUp = instr(htmlResult, "<title> MegaTokyo - relax, we understand j00</title>")

	if pageUp > 0 then

		htmlResult = Mid(htmlResult, InStr(htmlResult, "<!-- END OF HEADER -->"))
		htmlResult = Mid(htmlResult, InStr(htmlResult, "<IMG SRC=""/strips")+10)
		leftMark = 0
		rightMark = instr(htmlResult, "WIDTH") - 4

		if rightMark > leftMark Then

			'grabs the link of the comic
			comicLink = mid(htmlResult, 1, rightMark)

		end if

	Else
		getComicLink = "Latest comic link not available."

	end if

	getComicLink = comicLink

End Function


Private Function numToMonthName(num)

	Select Case num

	Case 1
		numToMonthName = "Jan"
	Case 2
		numToMonthName = "Feb"
	Case 3
		numToMonthName = "Mar"
	Case 4
		numToMonthName = "Apr"
	Case 5
		numToMonthName = "May"
	Case 6
		numToMonthName = "Jun"
	Case 7
		numToMonthName = "Jul"
	Case 8
		numToMonthName = "Aug"
	Case 9
		numToMonthName = "Sep"
	Case 10
		numToMonthName = "Oct"
	Case 11
		numToMonthName = "Nov"
	Case 12
		numToMonthName = "Dec"

	End Select

End Function


Private Function TimeDiff(file)
    dim fs,f,diff
    set fs=CreateObject("Scripting.FileSystemObject")
    if fs.fileexists(file) then
        set f=fs.GetFile(file)
        diff = datediff( "n", f.DateLastModified, now())
    else
        diff = -1
    end if
    set f=nothing
    set fs=nothing
    TimeDiff = diff
End Function

Private Function ReturnHTML(sURL)
	Dim objXMLHTTP,HTML
	Set objXMLHTTP = CreateObject("Microsoft.XMLHTTP")
	objXMLHTTP.Open "GET", sURL, False
	objXMLHTTP.Send
	HTML = objXMLHTTP.responseBody
	Set objRS = CreateObject("ADODB.Recordset")
	objRS.Fields.Append "txt", 200, 45000, &H00000080
	objRS.Open
	objRS.AddNew
	objRS.Fields("txt").AppendChunk HTML
	ReturnHTML = objRS("txt").Value
	objRS.Close
	Set objRS = Nothing
	Set objXMLHTTP = Nothing
End Function
